Geomancy
--------

.. include:: ../README.md
    :parser: myst_parser.sphinx_
    :start-after: <!-- start badges -->
    :end-before: <!-- end badges -->


.. include:: ../README.md
    :parser: myst_parser.sphinx_
    :start-after: <!-- start intro -->
    :end-before: <!-- end intro -->

Features
--------

.. include:: ../README.md
    :parser: myst_parser.sphinx_
    :start-after: <!-- start features -->
    :end-before: <!-- end features -->

.. toctree::
    :hidden:

    quickstart

.. toctree::
    :caption: Usage
    :hidden:


    usage/cmd_checks
    usage/cmd_run
    usage/format
    usage/checks/index

.. toctree::
    :caption: Guides
    :hidden:

    guides/tips_and_tricks

.. toctree::
    :caption: About the Project
    :hidden:

    about/changelog
    about/api/index
